@@ -12,12 +12,14 @@ Connect HTTP server and MESHTASTIC interface.
 from __future__ import annotations
 import logging
 from queue import SimpleQueue
+from datetime import datetime, timedelta
+
 from typing import Any, Optional
 
 from .config import Config
 from .http import start_receive_server
 from .meshtastic import create_announcer
-from .signals import message_received
+from .signals import message_received, queue_size_updated
 
 
 logger = logging.getLogger(__name__)
@@ -47,12 +49,16 @@ class Processor:
         """Log and announce an incoming message."""
         self.qn = self.qn + 1
         alert["qn"] = self.qn
+        alert["inputtime"] = (datetime.now() + timedelta(hours=2)).strftime(
+            '%Y-%m-%d %H:%M:%S'
+        )
         logger.debug(
             '\t [%s][%d] put in queue',
             alert["fingerprint"],
             alert["qn"],
         )
         self.message_queue.put((alert))
+        queue_size_updated.send(self.message_queue.qsize())
 
     def announce_message(self, alert: str) -> None:
         """Announce message on MESHTASTIC."""
@@ -66,6 +72,7 @@ class Processor:
             '\t [%s][%d] processing message ', alert["fingerprint"], alert["qn"]
         )
         self.announce_message(alert)
+        queue_size_updated.send(self.message_queue.qsize())
 
     def run(self) -> None:
         """Run the main loop."""
